@@ -19,7 +19,7 @@ import logging
 import re
 
 from BTrees import OOBTree  # pylint: disable=no-name-in-module
-from persistent.dict import PersistentDict
+from persistent.mapping import PersistentMapping
 from pyramid.events import subscriber
 from pyramid.threadlocal import get_current_registry
 from transaction.interfaces import ITransactionManager
@@ -113,7 +113,7 @@ class ImageThumbnailAdapter:
 
     def set_geometry(self, selection_name, geometry):
         """Set geometry for given selection name"""
-        geometries = get_annotation_adapter(self.image, THUMBNAIL_GEOMETRY_KEY, PersistentDict,
+        geometries = get_annotation_adapter(self.image, THUMBNAIL_GEOMETRY_KEY, PersistentMapping,
                                             notify=False, locate=False)
         geometries[selection_name] = geometry
         for current_thumbnail_name in list(self.thumbnails.keys()):
@@ -154,7 +154,7 @@ class ImageThumbnailAdapter:
                 if isinstance(selection, tuple):
                     selection, format = selection
                 else:
-                    format = 'jpeg'
+                    format = 'webp'
                 selection = FileFactory(selection)
                 alsoProvides(selection, IThumbnailFile)
                 registry.notify(ObjectCreatedEvent(selection))
@@ -193,7 +193,7 @@ class ImageThumbnailAdapter:
             # check for original image
             if size == self.get_image_size():
                 return self.image
-            # wee will look for default image thumbnailer
+            # we will look for default image thumbnailer
             thumbnailer_name = ''
             options = name
         else:
@@ -211,7 +211,7 @@ class ImageThumbnailAdapter:
                 if isinstance(thumbnail_image, tuple):
                     thumbnail_image, format = thumbnail_image
                 else:
-                    format = 'jpeg'
+                    format = 'webp'
                 # check watermark
                 if watermark is not None:
                     watermarker = query_utility(IWatermarker)
